Rdocumentation
powered by
Learn R Programming
rodd (version 0.2-1)
print.KLopt.lnorm: Short information about the input
Description
Prints short information about the input object of class ``KLopt.lnorm''.
Usage
"print"(x, ...)
Arguments
x
an object of type "KLopt.lnorm".
...
further arguments.
Details
List of models, list of fixed parameters and resulting design are displayed.
See Also
KLopt.lnorm
,
summary.KLopt.lnorm
,
plot.KLopt.lnorm